@@ -1,10 +1,10 @@
-
-use std::{net::Ipv4Addr, path::PathBuf, str::FromStr};
-use crate::engine::ServerMode;
-use log::LevelFilter;
 use clap::App;
+use log::{LevelFilter, trace};
+use std::{net::Ipv4Addr, path::PathBuf, str::FromStr};
+// #[cfg(feature="async")]
+// use crate::server::asynchronous::ServerMode;
 
-pub fn create_app() -> anyhow::Result<(Ipv4Addr, u16, ServerMode)> {
+pub fn create_app() -> anyhow::Result<(Ipv4Addr, u16)> {
     let yml = clap::load_yaml!("app.yml");
     let m = App::from_yaml(yml).get_matches();
     let termlog = LevelFilter::from_str(m.value_of("termlog").unwrap_or("info"))?;
@@ -12,14 +12,12 @@ pub fn create_app() -> anyhow::Result<(Ipv4Addr, u16, ServerMode)> {
     let logfile = PathBuf::from_str(m.value_of("logfile").unwrap_or("jokolink.log"))?;
     let ip_addr = Ipv4Addr::from_str(m.value_of("ip").unwrap_or("127.0.0.1"))?;
     let port = m.value_of("port").unwrap_or("7187").parse::<u16>()?;
-    let server_mode = match m.value_of("server").unwrap_or("udpsync") {
-        "udpsync" => ServerMode::UdpSync,
-        "udpasync" => ServerMode::UdpAsync,
-        "grpcasync" => ServerMode::GrpcAsync,
-        _ => anyhow::bail!("invalid server mode option from args"),
-    };
+ 
 
-    crate::log_init_panic(termlog, filelog, logfile)?;
-    Ok((ip_addr, port, server_mode))
+    crate::log_init(termlog, filelog, logfile)?;
+    trace!("created app and init log");
+
+    Ok((ip_addr, port))
+
+    
 }
-
