@@ -88,10 +88,9 @@ impl MumbleContext {
 }
 
 impl WindowDimensions {
-    #[cfg(target_os="windows")]
+    #[cfg(target_os = "windows")]
     pub fn update(&mut self, link_ptr: *const CMumbleLink) -> anyhow::Result<()> {
-
-        *self = crate::engine::win::get_win_pos_dim(link_ptr)?;
+        *self = crate::server::win::get_win_pos_dim(link_ptr)?;
         Ok(())
     }
 
@@ -109,4 +108,3 @@ unsafe impl bytemuck::Zeroable for WindowDimensions {
     }
 }
 unsafe impl bytemuck::Pod for WindowDimensions {}
-
